@@ -278,6 +278,21 @@ class DtUtil:
         """
         return dt.datetime.fromtimestamp(src_ts_ms / 1000)
 
+    @staticmethod
+    def convert_date_to_ts(src_dt: dt.datetime = dt.datetime.now()):
+        """把日期转成13位毫秒级时间戳
+        @param src_dt:日期
+        """
+        return int(src_dt.timestamp() * 1000)
+
+    @staticmethod
+    def convert_date_str_to_ts(src_dt_str: str, src_df: str = DF_STD_SEC):
+        """把日期字符串转成13位毫秒级时间戳
+        @param src_dt_str:源日期字符串
+        @param src_df:源日期字符串格式
+        """
+        return DtUtil.convert_date_to_ts(DtUtil.convert_str_to_date(src_dt_str, src_df))
+
     @staticmethod
     def convert_date_str_format(src_dt_str: str, src_df: str = DF_STD_SEC, dst_df: str = DF_CHN_DAY):
         """把日期字符串格式化成其他格式的日期字符串
@@ -816,10 +831,10 @@ class RedisUtil:
         'password': '',
         'db': '30000',
         'decode_responses': True,
+        'prefix': '',
     }
     """
-    CONN = None
-    CFID = None
+    CONN, CFID, PREFIX = None, None, None
 
     @classmethod
     def _init(cls, conf: dict):
@@ -831,6 +846,7 @@ class RedisUtil:
     @classmethod
     def connect(cls, conf: dict):
         try:
+            cls.PREFIX = conf.pop('prefix')
             pool = redis.ConnectionPool(**conf)
             cls.CONN = redis.Redis(connection_pool=pool)
             cls.CFID = UniUtil.get_uuid(conf)
@@ -841,28 +857,33 @@ class RedisUtil:
     def exist(cls, key: str):
         """判断key是否存在
         """
+        key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
         return cls.CONN.exists(key)
 
     @classmethod
     def get(cls, key: str):
         """字符串获取值
         """
+        key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
         return cls.CONN.get(key)
 
     @classmethod
     def set(cls, key: str, val: str):
         """字符串设置值
         """
+        key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
         cls.CONN.set(key, val)
 
     @classmethod
     def lget(cls, key: str):
         """列表获取值
         """
+        key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
         cls.CONN.lrange(key, 0, -1)
 
     @classmethod
     def lset(cls, key: dict, vals: tuple):
         """列表设置值
         """
+        key = f'{cls.PREFIX}:{key}' if cls.PREFIX else key
         cls.CONN.lpush(key, vals)
